@@ -20,6 +20,10 @@
 #ifndef MEDIAINFOGUI_ABOUT_NO
     #include "GUI/VCL/GUI_About.h"
 #endif
+#ifndef MEDIAINFOGUI_PLUGIN_NO
+    #include "GUI/VCL/GUI_Plugin.h"
+#endif
+
 //---------------------------------------------------------------------------
 
 //---------------------------------------------------------------------------
@@ -215,6 +219,7 @@ void __fastcall TMainF::GUI_Configure()
     else if (Prefs->Config(__T("Output"))==__T("XML")) {M_View_XMLClick(NULL); M_View_XML->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("MIXML")) {M_View_XMLClick(NULL); M_View_XML->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("JSON")) {M_View_JSONClick(NULL); M_View_JSON->Checked=true;}
+    else if (Prefs->Config(__T("Output"))==__T("Graph_Svg")) {M_View_Graph_SvgClick(NULL); M_View_Graph_Svg->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("MPEG-7")) {M_View_MPEG7Click(NULL); M_View_MPEG7->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("PBCore_1.2")) {M_View_PBCoreClick(NULL); M_View_PBCore->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("PBCore_2.0")) {M_View_PBCore2Click(NULL); M_View_PBCore2->Checked=true;}
@@ -837,6 +842,16 @@ void __fastcall TMainF::Refresh(TTabSheet *Page)
             I->Option_Static(__T("Inform"), __T("MIXML"));
         else if (M_View_JSON->Checked)
             I->Option_Static(__T("Inform"), __T("JSON"));
+        else if (M_View_Graph_Svg->Checked)
+        {
+            if (!Prefs->Config(__T("Graph_Adm_ShowTrackUIDs")).empty())
+                I->Option_Static(__T("Graph_Adm_ShowTrackUIDs"), Prefs->Config(__T("Graph_Adm_ShowTrackUIDs")));
+
+            if (!Prefs->Config(__T("Graph_Adm_ShowChannelFormats")).empty())
+                I->Option_Static(__T("Graph_Adm_ShowChannelFormats"), Prefs->Config(__T("Graph_Adm_ShowChannelFormats")));
+
+            I->Option_Static(__T("Inform"), __T("Graph_Svg"));
+        }
         else if (M_View_MPEG7->Checked)
             I->Option_Static(__T("Inform"), __T("MPEG-7"));
         else if (M_View_PBCore->Checked)
@@ -869,7 +884,67 @@ void __fastcall TMainF::Refresh(TTabSheet *Page)
             I->Option_Static(__T("Inform"), Prefs->Details[Prefs_Custom].Read());
         Ztring S1=I->Inform();
         if (S1.empty())
-            S1=Prefs->Translate(__T("At least one file")).c_str();
+			S1=Prefs->Translate(__T("At least one file")).c_str();
+
+        if (I->Option_Static(__T("Inform_Get"), __T("")) == __T("Graph_Svg"))
+        {
+            S1 = Ztring();
+
+            Ztring InstallFolder = Application->ExeName.c_str();
+            InstallFolder = InstallFolder.substr(0, InstallFolder.rfind(__T("\\")) + 1);
+
+            Ztring State=I->Option_Static(__T("Info_Graph_Svg_Plugin_State"), __T(""));
+            if (State == __T("0") || !File::Exists(InstallFolder+__T("\\Plugin\\Graph\\Template.html"))) //Try to install plugin
+            {
+                TPluginF* P = new TPluginF(this, PLUGIN_GRAPH);
+                if (P->Configure())
+                    P->ShowModal();
+                delete P;
+
+                State = I->Option_Static(__T("Info_Graph_Svg_Plugin_State"), __T(""));
+            }
+
+            if (State == __T("1"))
+            {
+                for (size_t Pos = 0; Pos < I->Count_Get(); Pos++)
+                {
+                    Ztring Svg = I->Inform(Pos);
+                    size_t Pos = Svg.find(__T("<svg"));
+                    if (Pos != std::string::npos)
+                        Svg = Svg.substr(Pos);
+                    S1 += (Pos ? __T("<br/>") : __T("")) + Svg;
+                }
+
+                if (File::Exists(InstallFolder+__T("\\Plugin\\Graph\\Template.html")))
+                {
+                    File F(InstallFolder+__T("\\Plugin\\Graph\\Template.html"));
+                    int8u* Buffer=new int8u[(size_t)F.Size_Get()+1];
+                    size_t Count=F.Read(Buffer, (size_t)F.Size_Get());
+                    if (Count==ZenLib::Error)
+                    {
+                        delete[] Buffer; //Buffer=NULL;
+                        S1=__T("Unable to load graph template");
+                    }
+                    else
+                    {
+                        Buffer[Count]=(int8u)'\0';
+                        Ztring Template=Ztring().From_UTF8((char*)Buffer);
+                        if (Template.FindAndReplace(__T("@SVG@"), S1)==0)
+                            S1=__T("Invalid template");
+                        else
+                            S1=Template;
+                    }
+                    delete[] Buffer; //Buffer=NULL;
+                }
+                else
+                    S1=__T("Graph template not found");
+            }
+            else if (State == __T("0"))
+                S1 = __T("Graph plugin not installed");
+            else
+                S1 = State;
+        }
+
         if (S1.size()>1 && S1[0]=='<' && S1[1]=='h')
         {
             //Supposing this is HTML
@@ -1181,6 +1256,14 @@ void __fastcall TMainF::M_View_NISO_Z39_87Click(TObject *Sender)
     ChangePage(Page_Custom);
 }
 
+//---------------------------------------------------------------------------
+void __fastcall TMainF::M_View_Graph_SvgClick(TObject *Sender)
+{
+    M_View_Graph_Svg->Checked=true;
+    ToolBar_View_Graph_Svg->Checked=true;
+    ChangePage(Page_Custom);
+}
+
 //---------------------------------------------------------------------------
 void __fastcall TMainF::M_View_PBCoreClick(TObject *Sender)
 {
@@ -1744,67 +1827,67 @@ MESSAGE void __fastcall TMainF::HandleDropFiles (TMessage& Msg)
 //---------------------------------------------------------------------------
 void __fastcall TMainF::Donate_deClick(TObject *Sender)
 {
-    ShellExecute(NULL, NULL, __T("http://MediaArea.net/MediaInfo/de/Donate"), NULL, NULL, SW_SHOWNORMAL);
+    ShellExecute(NULL, NULL, __T("https://MediaArea.net/MediaInfo/de/Donate"), NULL, NULL, SW_SHOWNORMAL);
 }
 
 //---------------------------------------------------------------------------
 void __fastcall TMainF::Donate_enClick(TObject *Sender)
 {
-    ShellExecute(NULL, NULL, __T("http://MediaArea.net/MediaInfo/en/Donate"), NULL, NULL, SW_SHOWNORMAL);
+    ShellExecute(NULL, NULL, __T("https://MediaArea.net/MediaInfo/en/Donate"), NULL, NULL, SW_SHOWNORMAL);
 }
 
 //---------------------------------------------------------------------------
 void __fastcall TMainF::Donate_esClick(TObject *Sender)
 {
-    ShellExecute(NULL, NULL, __T("http://MediaArea.net/MediaInfo/es/Donate"), NULL, NULL, SW_SHOWNORMAL);
+    ShellExecute(NULL, NULL, __T("https://MediaArea.net/MediaInfo/es/Donate"), NULL, NULL, SW_SHOWNORMAL);
 }
 
 //---------------------------------------------------------------------------
 void __fastcall TMainF::Donate_frClick(TObject *Sender)
 {
-    ShellExecute(NULL, NULL, __T("http://MediaArea.net/MediaInfo/fr/Donate"), NULL, NULL, SW_SHOWNORMAL);
+    ShellExecute(NULL, NULL, __T("https://MediaArea.net/MediaInfo/fr/Donate"), NULL, NULL, SW_SHOWNORMAL);
 }
 
 //---------------------------------------------------------------------------
 void __fastcall TMainF::Donate_itClick(TObject *Sender)
 {
-    ShellExecute(NULL, NULL, __T("http://MediaArea.net/MediaInfo/it/Donate"), NULL, NULL, SW_SHOWNORMAL);
+    ShellExecute(NULL, NULL, __T("https://MediaArea.net/MediaInfo/it/Donate"), NULL, NULL, SW_SHOWNORMAL);
 }
 
 //---------------------------------------------------------------------------
 void __fastcall TMainF::Donate_jaClick(TObject *Sender)
 {
-    ShellExecute(NULL, NULL, __T("http://MediaArea.net/MediaInfo/ja/Donate"), NULL, NULL, SW_SHOWNORMAL);
+    ShellExecute(NULL, NULL, __T("https://MediaArea.net/MediaInfo/ja/Donate"), NULL, NULL, SW_SHOWNORMAL);
 }
 
 //---------------------------------------------------------------------------
 void __fastcall TMainF::Donate_plClick(TObject *Sender)
 {
-    ShellExecute(NULL, NULL, __T("http://MediaArea.net/MediaInfo/pl/Donate"), NULL, NULL, SW_SHOWNORMAL);
+    ShellExecute(NULL, NULL, __T("https://MediaArea.net/MediaInfo/pl/Donate"), NULL, NULL, SW_SHOWNORMAL);
 }
 
 //---------------------------------------------------------------------------
 void __fastcall TMainF::Donate_zh_CNClick(TObject *Sender)
 {
-    ShellExecute(NULL, NULL, __T("http://MediaArea.net/MediaInfo/zh_CN/Donate"), NULL, NULL, SW_SHOWNORMAL);
+    ShellExecute(NULL, NULL, __T("https://MediaArea.net/MediaInfo/zh_CN/Donate"), NULL, NULL, SW_SHOWNORMAL);
 }
 
 //---------------------------------------------------------------------------
 void __fastcall TMainF::Donate_zh_TWClick(TObject *Sender)
 {
-    ShellExecute(NULL, NULL, __T("http://MediaArea.net/MediaInfo/zh_TW/Donate"), NULL, NULL, SW_SHOWNORMAL);
+    ShellExecute(NULL, NULL, __T("https://MediaArea.net/MediaInfo/zh_TW/Donate"), NULL, NULL, SW_SHOWNORMAL);
 }
 
 //---------------------------------------------------------------------------
 void __fastcall TMainF::Donate___Click(TObject *Sender)
 {
-    ShellExecute(NULL, NULL, (Ztring(__T("http://mediaarea.net/"))+Prefs->Translate(__T("  Language_ISO639"))+__T("MediaInfo/Donate")).c_str(), NULL, NULL, SW_SHOWNORMAL);
+    ShellExecute(NULL, NULL, (Ztring(__T("https://mediaarea.net/"))+Prefs->Translate(__T("  Language_ISO639"))+__T("MediaInfo/Donate")).c_str(), NULL, NULL, SW_SHOWNORMAL);
 }
 
 //---------------------------------------------------------------------------
 void __fastcall TMainF::M_NewVersionClick(TObject *Sender)
 {
-    ShellExecute(NULL, NULL, (Ztring(__T("http://mediaarea.net/"))+Prefs->Translate(__T("  Language_ISO639"))+__T("/MediaInfo/?NewVersionRequested=true")).c_str(), NULL, NULL, SW_SHOWNORMAL);
+    ShellExecute(NULL, NULL, (Ztring(__T("https://mediaarea.net/"))+Prefs->Translate(__T("  Language_ISO639"))+__T("/MediaInfo/?NewVersionRequested=true")).c_str(), NULL, NULL, SW_SHOWNORMAL);
 }
 
 //---------------------------------------------------------------------------
